"""Arc group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

ARC_TASKS = {
    "arc_ar": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_bn": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ca": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ca_challenge": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ca_easy": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_challenge": f"{BASE_IMPORT}arc_mc:ArcMultipleChoiceExtractor",
    "arc_challenge_chat": f"{BASE_IMPORT}arc_gen:ArcGenerationExtractor",
    "arc_challenge_llama": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_da": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_de": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_el": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_es": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_fi": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_hu": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_is": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_it": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_nb": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_pl": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_pt": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_challenge_mt_sv": f"{BASE_IMPORT}arc_challenge:ArcChallengeExtractor",
    "arc_da": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_de": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_easy": f"{BASE_IMPORT}arc_mc:ArcMultipleChoiceExtractor",
    "arc_es": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_eu": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_eu_challenge": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_eu_easy": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_fr": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_gu": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_hi": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_hr": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_hu": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_hy": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_id": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_it": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_kn": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ml": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_mr": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_multilingual": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ne": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_nl": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_pt": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ro": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ru": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_sk": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_sr": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_sv": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_ta": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_te": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_uk": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_vi": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
    "arc_zh": f"{BASE_IMPORT}okapi_arc_multilingual:OkapiArcMultilingualExtractor",
}
